const PersonnelFlowBar = (echarts: any) => {
  // 实例化对象
  const myChart = echarts.init(document.getElementById("personnelFlowBar"));
  // 配置项
  const option = {
    tooltip: {
      // 坐标轴指示器，坐标轴触发有效
      trigger: "axis",
      axisPointer: {
        // 默认为直线，可选为：'line' | 'shadow'
        type: "shadow"
      },
      formatter: function (params: any) {
        let str = params[0].name + "<br>";
        for (let item of params) {
          str += item.seriesName + " : " + item.value + "%<br>";
        }
        return str;
      }
    },
    legend: {
      icon: "circle",
      top: "-1%",
      right: "2%",
      itemGap: 20,
      textStyle: {
        fontSize: 12,//字体大小
        color: "#B8B8B8"//字体颜色
      }
    },
    grid: {
      top: "15%",
      left: "2%",
      right: "2%",
      bottom: "3%",
      containLabel: true
    },
    xAxis: [
      {
        type: "category",
        data: ["一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月"],
        axisTick: {
          alignWithLabel: true,
          show: false
        },
        // 修改坐标值样式
        axisLabel: {
          color: "#B8B8B8",
          fontSize: 16,
          show: true
        },
        axisLine: {
          show: false
        }
      }
    ],
    yAxis: [
      {
        type: "value",
        name: "%",
        // 修改坐标值样式
        axisLabel: {
          color: "#787E95",
          fontSize: 14
          // formatter: '{value} 人'
        },
        nameTextStyle: {
          color: "#787E95",
          fontSize: 16
        },
        // 修改坐标轴线样式
        axisLine: {
          show: true,
          lineStyle: {
            color: "transparent"
          }
        },
        axisTick: {
          show: false // 不显示坐标轴刻度线
        },
        splitLine: {
          lineStyle: {
            type: "dashed",
            color: "rgba(93,126,158,1)"
          }
        }
      }
    ],
    series: [
      {
        name: "今年",
        type: "bar",
        showBackground: false,
        barWidth: "15%",
        barGap: "80%",
        data: initData([12, 10, 23, 15, 3, 7, 11, 20, 17, 15, 8, 12]),
        // bar 样式修改
        itemStyle: {
          color: "#3EA1FF"
        }
      },
      {
        name: "去年",
        type: "bar",
        showBackground: false,
        barWidth: "15%",
        data: initData([7, 12, 8, 12, 12, 5, 8, 15, 18, 12, 9, 7]),
        // bar 样式修改
        itemStyle: {
          color: "#0ED8F9"
        }
      }
    ]
  };
  // 配置项给实例对象
  myChart.setOption(option);
  return myChart;
};

export default PersonnelFlowBar;


const initData = (arr: Array<number>) => {
  const total = _.reduce(arr, (pre: number, cur: number) => pre + cur, 0);
  const serie = [];
  for (let i = 0; i < arr.length; i++) {
    const num = arr[i];
    const numcount = Percentage(num, total);
    serie.push(numcount);
  }
  return serie;
};

const Percentage = (num: number, total: number) => {
  return (Math.round(num / total * 100));// 小数点后两位百分比
};
