const TrendsInSeparationsCharts = (echarts: any) => {
  // 实例化对象
  const myChart = echarts.init(document.getElementById("trendsInSeparationsCharts"));
  // 配置项
  const option = {
    tooltip: {
      // 坐标轴指示器，坐标轴触发有效
      trigger: "axis",
      axisPointer: {
        // 默认为直线，可选为：'line' | 'shadow'
        type: "shadow"
      }
    },
    legend: {
      icon: "circle",
      top: "5%",
      right: "center",
      itemGap: 20,
      textStyle: {
        fontSize: 12,//字体大小
        color: "#787E95"//字体颜色
      }
    },
    grid: {
      top: "20%",
      left: "2%",
      right: "2%",
      bottom: "3%",
      containLabel: true
    },
    xAxis: [
      {
        type: "category",
        data: ["一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月"],
        axisTick: {
          alignWithLabel: true,
          show: false
        },
        // 修改坐标值样式
        axisLabel: {
          color: "#B8B8B8",
          fontSize: 16,
          show: true
        },
        axisLine: {
          show: false
        }
      }
    ],
    yAxis: [
      {
        type: "value",
        name: "人",
        // 修改坐标值样式
        axisLabel: {
          color: "#787E95",
          fontSize: 14
          // formatter: '{value} 人'
        },
        nameTextStyle: {
          color: "#787E95",
          fontSize: 16
        },
        // 修改坐标轴线样式
        axisLine: {
          show: true,
          lineStyle: {
            color: "transparent"
          }
        },
        axisTick: {
          show: false // 不显示坐标轴刻度线
        },
        splitLine: {
          lineStyle: {
            type: "dashed",
            color: "rgba(93,126,158,1)"
          }
        }
      },
      {
        type: "value",
        // 修改坐标值样式
        axisLabel: {
          color: "#787E95",
          fontSize: 14,
          formatter: '{value} %'
        },
        nameTextStyle: {
          color: "#787E95",
          fontSize: 16
        },
        // 修改坐标轴线样式
        axisLine: {
          show: true,
          lineStyle: {
            color: "transparent"
          }
        },
        axisTick: {
          show: false // 不显示坐标轴刻度线
        },
        splitLine: {
          show: false,
          lineStyle: {
            type: "dashed",
            color: "rgba(93,126,158,1)"
          }
        }
      }
    ],
    series: [
      {
        name: "主动离职",
        type: "bar",
        stack:"Search Engine",
        showBackground: false,
        barWidth: "10%",
        barGap: "100%",
        data: [80, 30, 10, 38, 45, 70, 70, 70, 40, 50, 30, 10],
        // bar 样式修改
        itemStyle: {
          barBorderRadius: 2,
          color: "#00C48B"
        }
      },
      {
        name: "辞退",
        type: "bar",
        stack:"Search Engine",
        showBackground: false,
        barWidth: "10%",
        data: [20, 10, 5, 10, 10, 1, 1, 12, 10, 15, 5, 2],
        // bar 样式修改
        itemStyle: {
          barBorderRadius: 2,
          color: "#FFA400"
        }
      },
      {
        name: "离职率",
        type: "line",
        yAxisIndex: 1,
        data: [10, 4, 2, 5, 5, 7, 7, 10, 4, 6, 4, 2],
        itemStyle: {
          normal: {
            color: "#66EFE8",
            lineStyle: {
              color: "#66EFE8"
            }
          }
        },
      }
    ]
  };
  // 配置项给实例对象
  myChart.setOption(option);
  return myChart;
};

export default TrendsInSeparationsCharts;
