/*
 * Author: 黎永顺
 * name: 人员流量表
 * Description:
 * Date: 2023/4/27
 */
import React, { FunctionComponent, useEffect, useState } from "react";
// @ts-ignore
import echarts from "echarts";
import { Avatar, List } from "antd";
import FrameCard1 from "./components/frameCard1";
import FrameCard2 from "./components/frameCard2";
import FrameBox from "../components/frameBox";
import { frameCard1List, frameCard2List } from "@/pages/personnelReport/constants";
import PersonnelFlowBar from "./components/personnelFlowCharts";
import TrendsInSeparationsCharts from "./components/trendsInSeparationsCharts";
import { personnelFlowTablist, trainingRankingList } from "../constants";
import cs from "classnames";
import styles from "./index.less";

interface OwnProps {
}

type Props = OwnProps;

const index: FunctionComponent<Props> = (props) => {
  const [active, setActive] = useState<number>(0);
  useEffect(() => {
    const personnelFlowBar = PersonnelFlowBar(echarts);
    const trendsInSeparationsCharts = TrendsInSeparationsCharts(echarts);
    // 屏幕缩放对chart图表进行自适应处理，调用实例的resize方法
    window.onresize = () => {
      personnelFlowBar.resize();
      trendsInSeparationsCharts.resize();
    };
    return () => {
    };
  }, []);
  return (
    <div className={styles.peopleFlowWrapper}>
      <ul className={styles.headerCardWrapper}>
        <li>
          <FrameCard1
            title="在职人数"
            number="14338"
            unit="人"
            color="#78C0F9"
            isLine
            yoyIcon={require("../../../assets/images/down.png")}
            chainIcon={require("../../../assets/images/up.png")}
            yoyVal="4.75%"
            chainVal="4.75%"
            icon={require("../../../assets/images/zzrs.png")}
          />
        </li>
        {_.map(frameCard2List, (item: any, index: number) => {
          return (
            <li key={index} style={{ background: `url(${item.bg}) no-repeat` }}>
              <FrameCard2 {...item} />
            </li>
          );
        })}
      </ul>
      <div className={styles.contentBox}>
        <div className={styles.contentBoxLeft}>
          <div className={styles.contenBoxTop}>
            <div className={styles.chartsBox}>
              <ul>
                {_.map(frameCard1List, (item: any, index: number) => {
                  return (
                    <li key={index}>
                      <FrameCard1 {...item} />
                    </li>
                  );
                })}
              </ul>
              <div>
                <ul>
                  {
                    _.map(personnelFlowTablist, (item: any, index: number) => {
                      const classes = cs({
                        [styles["active"]]: index === active
                      });
                      return <li key={index} className={classes} onClick={() => setActive(index)}>{item}</li>;
                    })
                  }
                </ul>
                <div id="personnelFlowBar"/>
              </div>
            </div>

          </div>
          <div className={styles.contenBoxBottom}>
            <FrameBox title="离职情况变化趋势">
              <div className={styles.trendsInSeparations} id="trendsInSeparationsCharts"/>
            </FrameBox>
          </div>
        </div>
        <div className={styles.rankingBox}>
          <FrameBox title="培训排名">
            <div className={styles.trainingRanking}>
              <List
                dataSource={trainingRankingList}
                renderItem={(item, index) => (
                  <List.Item key={index}
                             className={cs({ [styles["rankRow"]]: index === 0 || index === 1 || index === 2 })}>
                    <List.Item.Meta
                      title={
                        <div className={styles.rankDescBox}>
                          {
                            (index === 0 || index === 1 || index === 2) ?
                              <img src={index === 0 ?
                                require("../../../assets/images/one.png") : index === 1 ?
                                  require("../../../assets/images/two.png") :
                                  require("../../../assets/images/three.png")} alt=""/> :
                              <span className={styles.rankNumber}>{index + 1}</span>
                          }
                          <div className={styles.rankDescPersBox}>
                            <Avatar src={item.avatar}/>
                            <span><span>{item.name}</span><span>{item.dept}</span></span>
                          </div>
                        </div>
                      }
                    />
                    <div style={{
                      fontWeight: (index === 0 || index === 1 || index === 2) ? 700 : 400,
                      fontSize: (index === 0 || index === 1 || index === 2) ? 16 : 14,
                      color: index === 0 ? "#FFA000" : index === 1 ? "#6F9DAE" : index === 2 ? "#B0442B" : "#333333"
                    }}>{item.score}</div>
                  </List.Item>
                )}
              />
            </div>
          </FrameBox>
        </div>
      </div>
    </div>
  );
};

export default index;
