/*
 * Author: 黎永顺
 * name: 报表大屏
 * Description:
 * Date: 2023/5/4
 */
import React, { FC, useEffect } from "react";
// @ts-ignore
import echarts from "echarts";
import "echarts-gl";
import TopPage from "./components/topPage";
import Map from "./components/map";
import FrameComp from "./components/frameComp";
import PersonnelCategoryBar from "./components/echarts/personnelCategoryBar";
import AgeStructureBar from "./components/echarts/ageStructureBar";
import DegreeStructurePie from "./components/echarts/degreeStructurePie";
import GradAnalysisPie from "./components/echarts/gradAnalysisPie";
import ChangeStatisticsBar from "./components/echarts/changeStatisticsBar";
import { salaryData, userOptions } from "./components/options";
// @ts-ignore
import { ScrollBoard } from "@jiaminghi/data-view-react";
import styles from "./index.less";

interface OwnProps {
}

type Props = OwnProps;
const Index: FC<Props> = (props) => {
  useEffect(() => {
    const personnelCategoryBar = PersonnelCategoryBar(echarts);
    const ageStructureBar = AgeStructureBar(echarts);
    const degreeStructurePie = DegreeStructurePie(echarts);
    const gradAnalysisPie = GradAnalysisPie(echarts);
    const changeStatisticsBar = ChangeStatisticsBar(echarts);
    // 屏幕缩放对chart图表进行自适应处理，调用实例的resize方法
    window.onresize = () => {
      personnelCategoryBar.resize();
      ageStructureBar.resize();
      degreeStructurePie.resize();
      gradAnalysisPie.resize();
      changeStatisticsBar.resize();
    };
    return () => {
    };
  }, []);

  return (
    <div className={styles.screenWrapperRoot}>
      <div className={styles.screenWrapper}>
        <TopPage/>
        <div className={styles.screenMain}>
          <div className={styles.screenCol}>
            <FrameComp position="bottom" tabList={["全部", "总部", "苏皖大区", "山东大区"]}
                       titleImg={require("../../../assets/images/rylbylb.png")}>
              <div className={styles.personnelCate} id="personnelCategory"/>
            </FrameComp>
            <FrameComp position="bottom" tabList={["全部", "总部", "苏皖大区"]}
                       titleImg={require("../../../assets/images/hxzgzgnljg.png")}>
              <div className={styles.ageStruct} id="ageStructure"/>
            </FrameComp>
          </div>
          <div className={styles.screenColCenter}>
            <ul className={styles.cardWrapper}>
              <li>
                <img src={require("../../../assets/images/xsje.png")} alt=""/>
                <div className={styles.cardInner}>
                  <span>8,29,000</span>
                  <span>销售金额</span>
                </div>
              </li>
              <li>
                <img src={require("../../../assets/images/xmys.png")} alt=""/>
                <div className={styles.cardInner}>
                  <span>3,29,000</span>
                  <span>项目验收</span>
                </div>
              </li>
              <li>
                <img src={require("../../../assets/images/yjgz.png")} alt=""/>
                <div className={styles.cardInner}>
                  <span>12,000</span>
                  <span>月均工资</span>
                </div>
              </li>
              <li>
                <img src={require("../../../assets/images/rwdcl.png")} alt=""/>
                <div className={styles.cardInner}>
                  <span>98%</span>
                  <span>任务达成率</span>
                </div>
              </li>
            </ul>
            <Map/>
          </div>
          <div className={styles.screenCol}>
            <FrameComp position="bottom" tabList={["全部", "总部", "苏皖大区"]}
                       titleImg={require("../../../assets/images/hxzgzgxljg.png")}>
              <div className={styles.degreeStructure} id="degreeStructure"></div>
            </FrameComp>
            <FrameComp position="bottom" tabList={["全部", "总部", "苏皖大区"]}
                       titleImg={require("../../../assets/images/hxzgzgdjfx.png")}>
              <div className={styles.gradAnalysis} id="gradAnalysis"></div>
            </FrameComp>
          </div>
        </div>
        <div className={styles.screenFooter}>
          <div className={styles.screenFooterCol}>
            <FrameComp position="right" tabList={["全部", "总部", "苏皖大区"]}
                       titleImg={require("../../../assets/images/zgxcfftj.png")}>
              <div className={styles.payrollStatistics}>
                <ScrollBoard
                  config={{
                    // 表头背景色
                    headerBGC: "#012B56",
                    // 奇数行背景色
                    oddRowBGC: "#042043",
                    // 偶数行背景色
                    evenRowBGC: "#00376D",
                    // 行号
                    index: false,
                    // 行号表头
                    // indexHeader: "序号",
                    // 宽度
                    // columnWidth: [],
                    // 对其方式
                    align: ["center"],
                    // 表行数
                    rowNum: 4,
                    ...userOptions(salaryData)
                  }}
                ></ScrollBoard>
              </div>
            </FrameComp>
          </div>
          <div className={styles.screenFooterCol}>
            <FrameComp position="right" tabList={["全部", "总部", "苏皖大区"]}
                       titleImg={require("../../../assets/images/hxzgzgrybdtj.png")}>
              <div className={styles.personnelChangeStatistics} id="changeStatistics"/>
            </FrameComp>
          </div>
        </div>
      </div>
    </div>
  );
};

export default Index;
