/*
 * Author: 黎永顺
 * name:人才利润报表
 * Description:
 * Date: 2023/4/27
 */
import React, { FC, useEffect, useState } from "react";
// @ts-ignore
import echarts from "echarts";
import { Avatar, List, Select } from "antd";
import FrameBox from "../components/frameBox";
import IncomeStatisticsRadar from "./components/incomStaticsRadar";
import TotalCostCharts from "./components/totalCostCharts";
import TotalLaborCostPerCapita from "./components/totalLaborCostPerCapita";
import OrgChart from "@/components/reactChart";
import CompanyItem from "./components/companyItem";
import RegionItem from "./components/regionItem";
import {
  humanRankingList,
  orgList,
  personRankingTablist,
  teamAnalysisRankingsOptions,
  teamRankingList,
  humanRankingList_1,
  humanRankingList_2
} from "../constants";
import cs from "classnames";
import styles from "./index.less";

interface OwnProps {
}

type Props = OwnProps;

const index: FC<Props> = (props) => {
  const [active, setActive] = useState<number>(0);
  useEffect(() => {
    const incomeStatisticsRadar = IncomeStatisticsRadar(echarts);
    const totalCostCharts = TotalCostCharts(echarts);
    const totalLaborCostPerCapita = TotalLaborCostPerCapita(echarts);
    // 屏幕缩放对chart图表进行自适应处理，调用实例的resize方法
    window.onresize = () => {
      incomeStatisticsRadar.resize();
      totalCostCharts.resize();
      totalLaborCostPerCapita.resize();
    };
    return () => {
    };
  }, []);
  // @ts-ignore
  return (
    <div className={styles.profitWrapper}>
      <div className={styles.profitHeader}>
        <div>
          <FrameBox title="数据看板">
            <div style={{ padding: 16, minHeight: 360, maxHeight: 360 }}>
              <table className={styles.dataTableWrapper}>
                <thead>
                <tr>
                  <th>调查类型</th>
                  <th>实际值</th>
                  <th>较去年同期</th>
                </tr>
                </thead>
                <tbody>
                <tr>
                  <td className={styles.title}>销售收入投资回报</td>
                  <td>
                    <div className={styles.dataVal}>
                      <span><span>3016</span><span>万元</span></span>
                      <span><span>同期值</span><span>3457</span></span>
                    </div>
                  </td>
                  <td className={styles.col3} style={{ color: "#FF4751" }}>
                    <img src={require("../../../assets/images/up.png")} alt=""/>
                    <span>4.75%</span>
                  </td>
                </tr>
                <tr>
                  <td className={styles.title}>人均净利润</td>
                  <td>
                    <div className={styles.dataVal}>
                      <span><span>17456</span><span>元</span></span>
                      <span><span>同期值</span><span>13567</span></span>
                    </div>
                  </td>
                  <td className={styles.col3} style={{ color: "#FF4751" }}>
                    <img src={require("../../../assets/images/up.png")} alt=""/>
                    <span>4.75%</span>
                  </td>
                </tr>
                <tr>
                  <td className={styles.title}>人均销售额</td>
                  <td>
                    <div className={styles.dataVal}>
                      <span><span>34.6</span><span>万元</span></span>
                      <span><span>同期值</span><span>45.16</span></span>
                    </div>
                  </td>
                  <td className={styles.col3} style={{ color: "#00BB7A" }}>
                    <img src={require("../../../assets/images/down.png")} alt=""/>
                    <span>4.75%</span>
                  </td>
                </tr>
                </tbody>
              </table>
            </div>
          </FrameBox>
        </div>
        <div>
          <FrameBox title="人员收入统计">
            <div className={styles.incomeStatisticsRadar} id="incomeStatisticsRadar"/>
          </FrameBox>
        </div>
        <div>
          <FrameBox title="团队分析排名">
            <div className={styles.teamRankingWrapper}>
              <Select defaultValue="1"
                      options={teamAnalysisRankingsOptions}
              />
              <List
                dataSource={teamRankingList}
                renderItem={(item, index) => (
                  <List.Item key={index}
                             className={cs({ [styles["rankRow"]]: index === 0 || index === 1 || index === 2 })}>
                    <List.Item.Meta
                      title={
                        <div
                          className={styles.rankDescBox}>
                          {
                            (index === 0 || index === 1 || index === 2) ?
                              <img src={index === 0 ?
                                require("../../../assets/images/one.png") : index === 1 ?
                                  require("../../../assets/images/two.png") :
                                  require("../../../assets/images/three.png")} alt=""/> :
                              <span className={styles.rankNumber}>{index + 1}</span>
                          }
                          <div className={styles.rankDescPersBox}>
                            {
                              (index === 0 || index === 1 || index === 2) &&
                              <Avatar src={item.avatar}/>
                            }
                            <span><span>{item.name}</span><span>{item.dept}</span></span>
                          </div>
                        </div>
                      }
                    />
                    <div style={{
                      fontWeight: (index === 0 || index === 1 || index === 2) ? 500 : 400,
                      fontSize: (index === 0 || index === 1 || index === 2) ? 16 : 14,
                      color: "#333333"
                    }}>{item.score}</div>
                  </List.Item>
                )}
              />
            </div>
          </FrameBox>
        </div>
        <div>
          <FrameBox title="人效分析排名">
            <div className={styles.personRankingWrapper}>
              <ul className={styles.rankingTabWrapper}>
                {
                  _.map(personRankingTablist, (item: any, index: number) => {
                    const classes = cs({
                      [styles["active"]]: index === active
                    });
                    return <li key={index} className={classes} onClick={() => setActive(index)}
                               title={item}>{item}</li>;
                  })
                }
              </ul>
              <List
                dataSource={active === 0 ? humanRankingList : active === 1 ? humanRankingList_1 : humanRankingList_2}
                renderItem={(item, index) => (
                  <List.Item key={index}
                             className={cs({ [styles["rankRow"]]: index === 0 || index === 1 || index === 2 })}>
                    <List.Item.Meta
                      title={
                        <div className={styles.rankDescBox}>
                          {
                            (index === 0 || index === 1 || index === 2) ?
                              <img src={index === 0 ?
                                require("../../../assets/images/one.png") : index === 1 ?
                                  require("../../../assets/images/two.png") :
                                  require("../../../assets/images/three.png")} alt=""/> :
                              <span className={styles.rankNumber}>{index + 1}</span>
                          }
                          <div className={styles.rankDescPersBox}>
                            {
                              (index === 0 || index === 1 || index === 2) &&
                              <Avatar src={item.avatar}/>
                            }
                            <span><span>{item.name}</span><span>{item.dept}</span></span>
                          </div>
                        </div>
                      }
                    />
                    <div style={{
                      fontWeight: (index === 0 || index === 1 || index === 2) ? 500 : 400,
                      fontSize: (index === 0 || index === 1 || index === 2) ? 16 : 14,
                      color: "#333333"
                    }}>{item.score}</div>
                  </List.Item>
                )}
              />
            </div>
          </FrameBox>
        </div>
      </div>
      <div className={styles.profitCenter}>
        <div>
          <FrameBox title="人工总成本">
            <div className={styles.totalLaborCost} id="totalCost"/>
          </FrameBox>
        </div>
        <div>
          <FrameBox title="人均人工总成本">
            <div className={styles.totalLaborCost} id="totalLaborCostPerCapita"/>
          </FrameBox>
        </div>
      </div>
      <div className={styles.profitBottom}>
        <FrameBox title="人工利润架构图">
          {/*@ts-ignore*/}
          {/*<FlowAnalysisGraph {...laborProfitDataConfig}/>*/}
          <OrgChart
            pan
            // zoom
            // maxZoom={2}
            // minZoom={0.5}
            // zoomStep={0.02}
            data={orgList} expandable
            renderNode={(node) => {
              const { key } = node;
              return (key === 0 || key === 1 || key === 2 || key === 3 || key === 4 || key === 5) ?
                <CompanyItem node={node}/> : <RegionItem node={node}/>;
            }}
          />
        </FrameBox>
      </div>
    </div>
  );
};

export default index;
