const MonthlyTrendsBar = (echarts: any) => {
  // 实例化对象
  const myChart = echarts.init(document.getElementById("monthlyTrendsCharts"));
  // 配置项
  const option = {
    tooltip: {
      // 坐标轴指示器，坐标轴触发有效
      trigger: "axis",
      axisPointer: {
        // 默认为直线，可选为：'line' | 'shadow'
        type: "shadow"
      }
    },
    grid: {
      top: "10%",
      left: "2%",
      right: "2%",
      bottom: "3%",
      containLabel: true
    },
    xAxis: [
      {
        type: "category",
        data: ["一月", "二月", "三月", "四月", "五月", "六月", "七月", "八月", "九月", "十月", "十一月", "十二月"],
        axisTick: {
          alignWithLabel: true,
          show: false
        },
        // 修改坐标值样式
        axisLabel: {
          color: "#B8B8B8",
          fontSize: 16,
          show: true
        },
        axisLine: {
          show: false
        }
      }
    ],
    yAxis: [
      {
        type: "value",
        name: "人",
        // 修改坐标值样式
        axisLabel: {
          color: "#787E95",
          fontSize: 14
          // formatter: '{value} 人'
        },
        nameTextStyle: {
          color: "#787E95",
          fontSize: 16
        },
        // 修改坐标轴线样式
        axisLine: {
          show: true,
          lineStyle: {
            color: "transparent"
          }
        },
        axisTick: {
          show: false // 不显示坐标轴刻度线
        },
        splitLine: {
          lineStyle: {
            type: "dashed",
            color: "rgba(93,126,158,1)"
          }
        }
      }
    ],
    series: [
      {
        name: "入职",
        type: "bar",
        showBackground: false,
        barWidth: "8%",
        barGap: "100%",
        data: [90, 70, 120, 60, 130, 80, 60, 125, 80, 60, 120, 40],
        // bar 样式修改
        itemStyle: {
          barBorderRadius: 5,
          color: "#0FC482"
        }
      },
      {
        name: "离职",
        type: "bar",
        showBackground: false,
        barWidth: "8%",
        data: [30, 50, 55, 25, 48, 30, 30, 75, 35, 20, 28, 10],
        // bar 样式修改
        itemStyle: {
          barBorderRadius: 5,
          color: "#FFA500"
        }
      },
      {
        name: "在职",
        type: "line",
        yAxisIndex: 0,
        data: [90, 70, 120, 60, 130, 110, 60, 125, 80, 60, 120, 40],
        itemStyle: {
          normal: {
            color: "#FFD700",
            lineStyle: {
              color: "#FFD700"
            }
          }
        },
        areaStyle: {
          normal: {
            color: {//分隔区域的颜色
              x0: 0,
              y0: 0,
              x2: 0,
              y2: 1,
              colorStops: [{
                offset: 0,
                color: "#FFD700" // 0% 处的颜色
              }, {
                offset: 1,
                color: "rgba(255,215,0,0)" // 100% 处的颜色；中间还可以设置50%、20%、70%时的颜色
              }],
              globalCoord: false // 缺省为 false，以确保上面的x,y,x2,y2表示的是百分比
            }
          }
        }
      }
    ]
  };
  // 配置项给实例对象
  myChart.setOption(option);
  return myChart;
};

export default MonthlyTrendsBar;
