/*
 * Author: 黎永顺
 * name: 卡片组件
 * Description:
 * Date: 2023/5/5
 */
import React, { FC } from "react";
import { TinyArea, TinyColumn } from "@ant-design/plots";
import styles from "./index.less";
import cs from "classnames";

interface OwnProps {
  title: string;
  active: number;
  number: string;
  unit: string;
  color: string;
  yoyVal?: string;
  chainVal?: string;
  yoyIcon?: any;
  chainIcon?: any;
  idx?: number;
  tabList: Array<any>;
  onTabChange?: any;
}

type Props = OwnProps;
const config = {
  height: 60,
  autoFit: false,
  data: [264, 417, 438, 887, 309, 397, 550],
  smooth: true,
  areaStyle: {
    fill: "#d6e3fd"
  },
  tooltip: {
    showCrosshairs: false,
    showContent: false
  }
};
const miniBarConfig = {
  height: 60,
  autoFit: false,
  data: [274, 337, 81, 497, 666, 219, 269],
  columnWidthRatio: 0.3,
  tooltip: {
    showCrosshairs: false,
    showContent: false
  }
};

const StructureCard: FC<Props> = (props) => {
  const { active, tabList, title, number, unit, color, yoyIcon, chainIcon, yoyVal, chainVal, idx, onTabChange } = props;
  const classes = cs(styles["center"], {
    [styles["vCenter"]]: (idx === 3 || idx === 4 || idx === 5)
  });

  return (
    <div className={styles.structureCardWrapper}>
      <div className={styles.top}>
        <span>{title}</span>
        <ul>
          {
            _.map(tabList, (it, index) => {
              const classes = cs({
                [styles["active"]]: index === active
              });
              return <li key={it} className={classes} onClick={() => onTabChange(idx, index)}>{it}</li>;
            })
          }
        </ul>
      </div>
      <div className={classes}>
        <div><span style={{ color }}>{number}</span><span>{unit}</span></div>
        <div className={styles.charts}>
          {
            idx === 5 ? <TinyColumn {..._.assign(miniBarConfig, {
                columnStyle: { fill: color }
              })}  /> :
              <TinyArea {..._.assign(config, {
                areaStyle: { fill: `l(270) 0:#fff 0.5:${color} 1:${color}` },
                line: { color }
              })} />
          }
        </div>
      </div>
      <div className={styles.bottom}>
        <span><span>同比：</span>{yoyIcon && <img src={yoyIcon} alt=""/>}<span>{yoyVal}</span></span>
        <span><span>环比：</span>{chainIcon && <img src={chainIcon} alt=""/>}<span>{chainVal}</span></span>
      </div>
    </div>
  );
};

export default StructureCard;
