/*
 * Author: 黎永顺
 * name: 人才结构表
 * Description:
 * Date: 2023/4/27
 */
import React, { FC, useEffect, useState } from "react";
// @ts-ignore
import echarts from "echarts";
import StructureCard from "./components/structureCard";
import StructureFrame from "./components/structureFrame";
import MonthlyTrendsBar from "./components/monthlyTrendsCharts";
import RankingBar from "./components/rankingCharts";
import AgeStaticsPie from "./components/ageStaticsCharts";
import GenderStaticsPie from "./components/genderStaticsCharts";
import LineStaticsPie from "./components/lineStaticsCharts";
import InternStaticsBar from "./components/internStaticsCharts";
import EducationStaticsRedar from "./components/educationStaticsCharts";
import { structureCardList } from "../constants";
import styles from "./index.less";

interface OwnProps {
}

type Props = OwnProps;

const index: FC<Props> = (props) => {
  const [card, setCard] = useState<any>(structureCardList);
  useEffect(() => {
    const monthlyTrendsBar = MonthlyTrendsBar(echarts);
    const rankingBar = RankingBar(echarts);
    const ageStaticsPie = AgeStaticsPie(echarts);
    const genderStaticsPie = GenderStaticsPie(echarts);
    const lineStaticsPie = LineStaticsPie(echarts);
    const internStaticsBar = InternStaticsBar(echarts);
    const educationStaticsRedar = EducationStaticsRedar(echarts);
    // 屏幕缩放对chart图表进行自适应处理，调用实例的resize方法
    window.onresize = () => {
      monthlyTrendsBar.resize();
      rankingBar.resize();
      ageStaticsPie.resize();
      genderStaticsPie.resize();
      lineStaticsPie.resize();
      internStaticsBar.resize();
      educationStaticsRedar.resize();
    };
    return () => {
    };
  }, []);

  const handleChangeTab = (itemIdx: number, val: number) => {
    setCard(_.map(card, (item, idex: number) => {
        if (idex === itemIdx) {
          return { ...item, active: val };
        }
        return { ...item };
      }
    ));
  };

  return (
    <div className={styles.structureWrapper}>
      <ul className={styles.structureColumn_1}>
        {
          _.map(card, (it, idx) => {
            return <li key={idx}><StructureCard {...it} idx={idx} onTabChange={handleChangeTab}/></li>;
          })
        }
      </ul>
      <div className={styles.structureColumn_2}>
        <StructureFrame title="人员结构统计">
          <div className={styles.multipleCharts}>
            <div><span>司龄统计</span>
              <div id="ageStatics"/>
            </div>
            <div><span>性别统计</span>
              <div id="genderStatics"/>
            </div>
            <div><span>学历统计</span>
              <div id="educationStatics"/>
            </div>
            <div><span>条线统计</span>
              <div id="lineStatics"/>
            </div>
            <div><span>实习生统计</span>
              <div id="internStatics"/>
            </div>
          </div>
        </StructureFrame>
      </div>
      <div className={styles.structureColumn_3}>
        <div>
          <StructureFrame title="人员流动情况月度趋势" tabList={["今年", "去年"]}>
            <div className={styles.monthlyTrendsChartsBox} id="monthlyTrendsCharts"/>
          </StructureFrame>
        </div>
        <div>
          <StructureFrame title="机构人员排名数">
            <div className={styles.rankingChartsBox} id="rankingCharts"/>
          </StructureFrame>
        </div>
      </div>
    </div>
  );
};

export default index;
