/**
 * 上传地址
 * @returns {*}
 */
import config from "@/config";
import { Session } from "../utils";

/**
 * 上传成功返回详情信息
 * @returns {string}
 */
export const uploadURLReturnDetail = () => {
  return config.get("file/uploadReturnDetail");
};

/**
 * 上传成功仅返回fileId
 * @returns {string}
 */
export const uploadURLReturnId = () => {
  return config.get("file/uploadReturnId");
};

/**
 * 文件下载地址
 * @param fileId
 * @returns {string}
 */
export const downloadURL = (fileId) => {
  const token = Session.getAccessToken() || Session.getRefreshToken();
  return config.get("file/download") + "/" + fileId + `?access_token=${token}`;
};

/**
 * 头像/图片查看地址
 * @param fileId
 * @returns {string}
 */
export const viewImg = (fileId) => {
  const token = Session.getAccessToken() || Session.getRefreshToken();
  return config.get("file/viewImg") + "/" + fileId + `?access_token=${token}`;
};

/**
 * 获取图片后缀
 * @returns {string}
 */
export const getPicSuffix = () => {
  return config.get("picSuffix");
};

/**
 * 判断是否为JSON字符串
 * @returns {string}
 */
export const exceptStr = (str) => {
  try {
    return JSON.parse(str);
  } catch (err) {
    return {};
  }
};
/**
 * @param {date} time 需要转换的时间
 * @param {String} fmt 需要转换的格式 如 yyyy-MM-dd、yyyy-MM-dd HH:mm:ss
 */
export const formatTime = (time, fmt) => {
  if (!time) return "";
  else {
    const date = new Date(time);
    const o = {
      "M+": date.getMonth() + 1,
      "d+": date.getDate(),
      "H+": date.getHours(),
      "m+": date.getMinutes(),
      "s+": date.getSeconds(),
      "q+": Math.floor((date.getMonth() + 3) / 3),
      S: date.getMilliseconds()
    };
    if (/(y+)/.test(fmt))
      fmt = fmt.replace(
        RegExp.$1,
        (date.getFullYear() + "").substr(4 - RegExp.$1.length)
      );
    for (const k in o) {
      if (new RegExp("(" + k + ")").test(fmt)) {
        fmt = fmt.replace(
          RegExp.$1,
          RegExp.$1.length === 1
            ? o[k]
            : ("00" + o[k]).substr(("" + o[k]).length)
        );
      }
    }
    return fmt;
  }
};
export const debounce = (func, wait, immediate) => {
  let timeout, args, context, timestamp, result;

  const later = function () {
    // 据上一次触发时间间隔
    const last = +new Date() - timestamp;

    // 上次被包装函数被调用时间间隔 last 小于设定时间间隔 wait
    if (last < wait && last > 0) {
      timeout = setTimeout(later, wait - last);
    } else {
      timeout = null;
      // 如果设定为immediate===true，因为开始边界已经调用过了此处无需调用
      if (!immediate) {
        result = func.apply(context, args);
        if (!timeout) context = args = null;
      }
    }
  };

  return function (...args) {
    context = this;
    timestamp = +new Date();
    const callNow = immediate && !timeout;
    // 如果延时不存在，重新设定延时
    if (!timeout) timeout = setTimeout(later, wait);
    if (callNow) {
      result = func.apply(context, args);
      context = args = null;
    }

    return result;
  };
};

export const paginationFun = (tableListPageObj, sizeChange, onChange) => {
  return {
    current: tableListPageObj.pageNum,
    pageSize: tableListPageObj.size,
    total: tableListPageObj.total,
    showTotal: (total) => `共 ${total} 条`,
    showQuickJumper: true,
    showSizeChanger: true,
    pageSizeOptions: ["10", "20", "50", "100"],
    onShowSizeChange: () => sizeChange(),
    onChange: (page, size) => {
      const { total } = tableListPageObj;
      onChange({
        pageNum: page,
        size,
        total
      });
    }
  };
};
